abacusai.presentation_export_result — AbacusAI documentation

# abacusai.presentation_export_result

## Classes

`PresentationExportResult` | Export Presentation

## Module Contents

class abacusai.presentation_export_result.PresentationExportResult(client, filePath=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Export Presentation

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - filePath (str) – The path to the exported presentation

  file_path = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict